window.Gleam.initSearch([{"doc":"gsv","title":"gsv","content":"# gsv\n\n[![Package Version](https://img.shields.io/hexpm/v/gsv)](https://hex.pm/packages/gsv)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gsv/)\n\nThis is a simple csv parser and writer for Gleam. It will get more performant/battle tested in the future,\nbut if you&#39;re looking for that now, I&#39;d recommend doing ffi to an existing parser in your target runtime.\n\n#### Example\n\n```gleam\nimport gsv.{Unix, Windows}\n\npub fn main() {\n  let csv_str = &quot;Hello, World\\nGoodbye, Mars&quot;\n\n  // Parse a CSV string to a List(List(String))\n  let assert Ok(records) = gsv.to_lists(csv_str)\n\n  // Write a List(List(String)) to a CSV string\n  let csv_str = records\n  |&gt; gsv.from_lists(separator: &quot;,&quot;, line_ending: Windows)\n\n  // Parse a CSV string with headers to a List(Dict(String, String))\n  let assert Ok(records) = gsv.to_dicts(csv_str)\n  // =&gt; [ dict.from_list([ #(&quot;Hello&quot;, &quot;Goodbye&quot;), #(&quot;World&quot;, &quot;Mars&quot;) ]) ]\n\n  // Write a List(Dict(String, String)) to a CSV string, treating the keys as the header row\n  let csv_str = records\n    |&gt; gsv.from_dicts(separator: &quot;,&quot;, line_ending: Windows)\n}\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add gsv\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/gsv&gt;.\n","url":"index.html"},{"doc":"gsv","title":"LineEnding","content":"pub type LineEnding {\n  Windows\n  Unix\n}\n Option for using &quot;\\n = LF = Unix&quot; or &quot;\\r\\n = CRLF = Windows&quot;\n line endings. Use with the `from_lists` function when \n writing to a csv string.\nWindows\n\n\nUnix\n\n\nSynonyms:\ngsv.LineEnding\ngsv LineEnding","url":"gsv.html#LineEnding"},{"doc":"gsv","title":"from_dicts","content":"pub fn from_dicts(\n  input: List(Dict(String, String)),\n  separator separator: String,\n  line_ending line_ending: LineEnding,\n) -&gt; String\n Takes a list of dicts and writes it to a csv string.\n Will automatically escape strings that contain double quotes or\n line endings with double quotes (in csv, double quotes get escaped by doing\n a double doublequote)\n The string `he&quot;llo\\n` becomes `&quot;he&quot;&quot;llo\\n&quot;`\nSynonyms:\ngsv.from_dicts\ngsv from_dicts","url":"gsv.html#from_dicts"},{"doc":"gsv","title":"from_lists","content":"pub fn from_lists(\n  input: List(List(String)),\n  separator separator: String,\n  line_ending line_ending: LineEnding,\n) -&gt; String\n Takes a list of lists of strings and writes it to a csv string.\n Will automatically escape strings that contain double quotes or\n line endings with double quotes (in csv, double quotes get escaped by doing\n a double doublequote)\n The string `he&quot;llo\\n` becomes `&quot;he&quot;&quot;llo\\n&quot;`\nSynonyms:\ngsv.from_lists\ngsv from_lists","url":"gsv.html#from_lists"},{"doc":"gsv","title":"to_dicts","content":"pub fn to_dicts(\n  input: String,\n) -&gt; Result(List(Dict(String, String)), String)\n Parses a csv string to a list of dicts. \n Automatically handles Windows and Unix line endings.\n Returns a string error msg if the string is not valid csv.\n Unquoted strings are trimmed, while quoted strings have leading and trailing \n whitespace preserved.\n Whitespace only or empty strings are not valid headers and will be ignored. \n Whitespace only or empty strings are not considered &quot;present&quot; in the csv row and \n are not inserted into the row dict. \nSynonyms:\ngsv.to_dicts\ngsv to_dicts","url":"gsv.html#to_dicts"},{"doc":"gsv","title":"to_lists","content":"pub fn to_lists(\n  input: String,\n) -&gt; Result(List(List(String)), String)\n Parses a csv string to a list of lists of strings.\n Automatically handles Windows and Unix line endings.\n Returns a string error msg if the string is not valid csv.\n Unquoted strings are trimmed, while quoted strings have leading and trailing \n whitespace preserved.\nSynonyms:\ngsv.to_lists\ngsv to_lists","url":"gsv.html#to_lists"},{"doc":"gsv","title":"gsv","content":"","url":"gsv.html"}]);